API
====

## Important classes

  * [Board](/api/board)
    * [TiledBoard](/api/board.tiledboard)
    * [PixelBoard](/api/board.pixelboard)
* [Token](/api/token)

## Full API

```{eval-rst}
.. toctree::
   :maxdepth: 1
   :glob:
   
   api/*
```